@@ -10,18 +10,14 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.assertions._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_secretsmanager._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-secret-manager-wrapper-layer",
-    "1.0.435",
+    "2.0.249",
     __name__[0:-6],
-    "cdk-secret-manager-wrapper-layer@1.0.435.jsii.tgz",
+    "cdk-secret-manager-wrapper-layer@2.0.249.jsii.tgz",
 )
 
 __all__ = [
